diff python/moving.py @ 768:f8e0a8ea8402 dev

updated the bounding box code (the name so that it is general for ground truth and UT)
author Nicolas Saunier <nicolas.saunier@polymtl.ca>
date Thu, 14 Jan 2016 11:44:39 -0500
parents d6f0e0cab07d
children bd13937818a4
line wrap: on
line diff
--- a/python/moving.py	Mon Dec 21 15:16:33 2015 -0500
+++ b/python/moving.py	Thu Jan 14 11:44:39 2016 -0500
@@ -1560,15 +1560,19 @@
 # Annotations
 ##################
 
-class BBAnnotation(MovingObject):
-    '''Class for a series of ground truth annotations using bounding boxes
-    Its center is the center of the containing shape
+class BBMovingObject(MovingObject):
+    '''Class for a moving object represented as a bounding box
+    used for series of ground truth annotations using bounding boxes
+     and for the output of Urban Tracker http://www.jpjodoin.com/urbantracker/
 
     By default in image space
+
+    Its center is the center of the box (generalize to other shapes?) 
+    (computed after projecting if homography available)
     '''
 
     def __init__(self, num = None, timeInterval = None, topLeftPositions = None, bottomRightPositions = None, userType = userType2Num['unknown']):
-        super(BBAnnotation, self).__init__(num, timeInterval, userType = userType)
+        super(BBMovingObject, self).__init__(num, timeInterval, userType = userType)
         self.topLeftPositions = topLeftPositions.getPositions()
         self.bottomRightPositions = bottomRightPositions.getPositions()
 
@@ -1595,7 +1599,7 @@
     Keni, Bernardin, and Stiefelhagen Rainer. "Evaluating multiple object tracking performance: the CLEAR MOT metrics." EURASIP Journal on Image and Video Processing 2008 (2008)
 
     objects and annotations are supposed to in the same space
     current implementation is BBAnnotations (bounding boxes)
     mathingDistance is threshold on matching between annotation and object
 
     TO: tracker output (objects)
@@ -1595,7 +1599,7 @@
 
     objects and annotations are supposed to in the same space
-    current implementation is BBAnnotations (bounding boxes)
+    current implementation is BBMovingObject (bounding boxes)
     mathingDistance is threshold on matching between annotation and object
 